guix_mirror_bot pushed a commit to branch master
in repository guix.

commit bedb35f7a59847929060c4f371db2f47493e99dc
Author: Hilton Chain <[email protected]>
AuthorDate: Tue Aug 12 23:59:32 2025 +0800

    gnu: fcitx5-chinese-addons: Update package style.
    
    * gnu/packages/fcitx5.scm (fcitx5-chinese-addons) [arguments]: Use
    G-expressions.
    [inputs]: Remove labels.
    
    Change-Id: I695a4893df68a6b6cd00142cc626ea010385336c
---
 gnu/packages/fcitx5.scm | 44 ++++++++++++++++++++++----------------------
 1 file changed, 22 insertions(+), 22 deletions(-)

diff --git a/gnu/packages/fcitx5.scm b/gnu/packages/fcitx5.scm
index 1f81262745..e940d6f2d9 100644
--- a/gnu/packages/fcitx5.scm
+++ b/gnu/packages/fcitx5.scm
@@ -456,29 +456,29 @@ backend.")
         (base32 "0j0xx4kil93ixa81j08y4mm5qfpl32qf3fdlcw2sbjn92v238hbv"))))
     (build-system cmake-build-system)
     (arguments
-     `(#:configure-flags
-       '("-DUSE_WEBKIT=off")
-       #:phases
-       (modify-phases %standard-phases
-         (add-before 'configure 'split-outputs
-           ;; Build with GUI supports requires Qt and increase package closure
-           ;; by 800M on x86_64, so place it under another output.
-           (lambda* (#:key outputs #:allow-other-keys)
-             (substitute* "gui/pinyindictmanager/CMakeLists.txt"
-               (("\\$\\{CMAKE_INSTALL_LIBDIR\\}" _)
-                (string-append (assoc-ref outputs "gui") "/lib"))))))))
+     (list #:configure-flags
+           #~(list "-DUSE_WEBKIT=off")
+           #:phases
+           #~(modify-phases %standard-phases
+               (add-before 'configure 'split-outputs
+                 ;; Build with GUI supports requires Qt and increase package
+                 ;; closure by 800M on x86_64, so place it under another 
output.
+                 (lambda _
+                   (substitute* "gui/pinyindictmanager/CMakeLists.txt"
+                     (("\\$\\{CMAKE_INSTALL_LIBDIR\\}" _)
+                      (string-append #$output:gui "/lib"))))))))
     (inputs
-     `(("fcitx5" ,fcitx5)
-       ("fcitx5-lua" ,fcitx5-lua)
-       ("boost" ,boost)
-       ("libime",libime)
-       ("curl" ,curl)
-       ("gettext" ,gettext-minimal)
-       ("fmt" ,fmt)
-       ("opencc" ,opencc)
-       ("qtbase" ,qtbase)
-       ("fcitx5-qt" ,fcitx5-qt)
-       ("qtwebengine" ,qtwebengine)))
+     (list boost
+           curl
+           fcitx5
+           fcitx5-lua
+           fcitx5-qt
+           fmt
+           gettext-minimal
+           libime
+           opencc
+           qtbase
+           qtwebengine))
     (native-inputs
      (list extra-cmake-modules pkg-config))
     (outputs '("out" "gui"))

Reply via email to